function [r_vec, v_vec] = kep2ECI(a,e,i, omega, RA, mu, t, t0, MA0)

% 1.	Compute the mean anomaly, MA, (0? ? 360?),
n = vpa(sqrt(mu/a^3));
MA = n*(t-t0)+MA0;

% 2.	Compute the eccentric anomaly, EA, (radians),
syms EA
EA_s = solve(0 == EA - e*sin(EA)- MA, EA);
EA = EA_s;
% 3.	Compute the true anomaly,  (radians)
syms theta
theta_s = solve(tan(theta/2)==vpa(sqrt((1+e)/(1-e)))*tan(EA/2), theta);
theta = theta_s;
ang = double(theta*180/pi);

%  If EA < 180? then  < 180? (There is no need to do a quadrant check.  The equation above will automatically yield the correct value of  .)

% 4.	Compute the radius, r,
r = vpa(a*(1-e*cos(EA))); 

% 5.	Compute the specific angular momentum, h, 
h = vpa(sqrt(mu*a*(1-e^2)));

% 6.	Compute the position components, X,Y,Z
x = r*(cos(RA)*cos(omega+theta)-sin(RA)*sin(omega+theta)*cos(i));
y = r*(sin(RA)*cos(omega+theta)+cos(RA)*sin(omega+theta)*cos(i));
z = r*(sin(omega+theta)*sin(i));
 
p = double(a*(1-e^2));
% 7.   Compute the velocity components
x_dot = vpa((x*h*e/(r*p)))*sin(theta)-vpa((h/r))*(cos(RA)*sin(omega+theta)+sin(RA)*cos(omega+theta)*cos(i));
y_dot = vpa((y*h*e/(r*p)))*sin(theta)-vpa((h/r))*(sin(RA)*sin(omega+theta)-cos(RA)*cos(omega+theta)*cos(i));
z_dot = vpa((z*h*e/(r*p)))*sin(theta)+vpa((h/r))*cos(omega+theta)*sin(i);


r_vec = double([x, y, z]);
v_vec = double([x_dot, y_dot, z_dot]);

end